pyparsing.pyparsing.Token

Package pyparsing :: Module pyparsing :: Class Token |
[frames] | no frames]

# Class Token

source code

       object --+
                |
    ParserElement --+
                    |
                   Token

Known Subclasses:
  - Literal
  - , Empty
  - , Keyword
  - , CharsNotIn
  - , _PositionToken
  - , NoMatch
  - , QuotedString
  - , Regex
  - , White
  - , Word

Abstract `ParserElement` subclass, for defining atomic matching patterns.

Nested Classes
Inherited from `ParserElement`: `literalStringClass`

Instance Methods
__init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
setName(self, name) Define name for this expression, for use in debugging. | source code
Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__hash__`, `__invert__`, `__mul__`, `__ne__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__rne__`, `__ror__`, `__rsub__`, `__rxor__`, `__str__`, `__sub__`, `__xor__`, `addParseAction`, `checkRecursion`, `copy`, `ignore`, `leaveWhitespace`, `parseFile`, `parseImpl`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setFailAction`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `streamline`, `suppress`, `transformString`, `tryParse`, `validate` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `ParserElement`: `enablePackrat`, `inlineLiteralsUsing`, `resetCache`, `setDefaultWhitespaceChars`

Class Variables
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`, `verbose_stacktrace`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### setName(self, name) | source code
Define name for this expression, for use in debugging. Overrides: ParserElement.setName (inherited documentation)